%global gittag r1rv58
%global classname org.bouncycastle.jce.provider.BouncyCastleProvider

Summary:          Bouncy Castle Cryptography APIs for Java
Name:             bouncycastle1.58
Version:          1.58
Release:          1%{?dist}
License:          MIT
URL:              http://www.bouncycastle.org

Source0:          https://github.com/bcgit/bc-java/archive/%{gittag}/bouncycastle-%{version}.tar.gz

# POMs from Maven Central
Source1:          http://repo1.maven.org/maven2/org/bouncycastle/bcprov-jdk15on/%{version}/bcprov-jdk15on-%{version}.pom
Source2:          http://repo1.maven.org/maven2/org/bouncycastle/bcpkix-jdk15on/%{version}/bcpkix-jdk15on-%{version}.pom
Source3:          http://repo1.maven.org/maven2/org/bouncycastle/bcpg-jdk15on/%{version}/bcpg-jdk15on-%{version}.pom
Source4:          http://repo1.maven.org/maven2/org/bouncycastle/bcmail-jdk15on/%{version}/bcmail-jdk15on-%{version}.pom
Source5:          http://repo1.maven.org/maven2/org/bouncycastle/bctls-jdk15on/%{version}/bctls-jdk15on-%{version}.pom

BuildArch:        noarch

BuildRequires:    ant
BuildRequires:    ant-junit
BuildRequires:    ant-trax
BuildRequires:    javamail
BuildRequires:    java-devel
BuildRequires:    jpackage-utils

Requires:         java
Requires:         jpackage-utils
Requires(post):   jpackage-utils
Requires(postun): jpackage-utils

%description
The Bouncy Castle Crypto package is a Java implementation of cryptographic
algorithms. This jar contains JCE provider and lightweight API for the
Bouncy Castle Cryptography APIs for JDK 1.5 to JDK 1.8.

%package pkix
Summary:          Bouncy Castle PKIX, CMS, EAC, TSP, PKCS, OCSP, CMP, and CRMF APIs
Requires:         java
Requires:         jpackage-utils
Requires:         %{name} = %{version}-%{release}

%description pkix
The Bouncy Castle Java APIs for CMS, PKCS, EAC, TSP, CMP, CRMF, OCSP, and
certificate generation. This jar contains APIs for JDK 1.5 to JDK 1.8. The
APIs can be used in conjunction with a JCE/JCA provider such as the one
provided with the Bouncy Castle Cryptography APIs.

%package pg
Summary:          Bouncy Castle OpenPGP API
License:          MIT and ASL 2.0
Requires:         java
Requires:         jpackage-utils
Requires:         %{name} = %{version}-%{release}

%description pg
The Bouncy Castle Java API for handling the OpenPGP protocol. This jar
contains the OpenPGP API for JDK 1.5 to JDK 1.8. The APIs can be used in
conjunction with a JCE/JCA provider such as the one provided with the
Bouncy Castle Cryptography APIs.

%package mail
Summary:          Bouncy Castle S/MIME API
Requires:         java
Requires:         jpackage-utils
Requires:         %{name} = %{version}-%{release}
Requires:         %{name}-pkix = %{version}-%{release}

%description mail
The Bouncy Castle Java S/MIME APIs for handling S/MIME protocols. This jar
contains S/MIME APIs for JDK 1.5 to JDK 1.8. The APIs can be used in
conjunction with a JCE/JCA provider such as the one provided with the Bouncy
Castle Cryptography APIs. The JavaMail API and the Java activation framework
will also be needed.

%package tls
Summary:          Bouncy Castle JSSE provider and TLS/DTLS API
Requires:         java
Requires:         jpackage-utils
Requires:         %{name} = %{version}-%{release}

%description tls
The Bouncy Castle Java APIs for TLS and DTLS, including a provider for the
JSSE.

%package javadoc
Summary:          Javadoc for %{name}
Requires:         jpackage-utils

%description javadoc
API documentation for the Bouncy Castle Cryptography APIs.

%prep
%setup -q -n bc-java-%{gittag}

# Remove provided binaries
find . -type f -name "*.class" -exec rm -f {} \;
find . -type f -name "*.jar" -exec rm -f {} \;

# Set expected source encoding
sed -i -e '/<javadoc/aencoding="UTF-8"' \
       -e '/<javac/aencoding="UTF-8"' ant/bc+-build.xml

cp -p %{SOURCE1} bcprov.pom
cp -p %{SOURCE2} bcpkix.pom
cp -p %{SOURCE3} bcpg.pom
cp -p %{SOURCE4} bcmail.pom
cp -p %{SOURCE5} bctls.pom

%build
ant -f ant/jdk15+.xml \
  -Djunit.jar.home=$(build-classpath junit) \
  -Dmail.jar.home=$(build-classpath javamail/javax.mail) \
  -Dactivation.jar.home= \
  -Drelease.debug=true \
  clean build-provider build test

# Not shipping the "lcrypto" jar, so don't ship the javadoc for it
rm -rf build/artifacts/jdk1.5/javadoc/lcrypto

%install
install -dm 755 %{buildroot}%{_sysconfdir}/java/security/security.d
touch %{buildroot}%{_sysconfdir}/java/security/security.d/2158-%{classname}

mkdir -p %{buildroot}%{_javadir}
mkdir -p %{buildroot}%{_mavenpomdir}

for bc in bcprov bcpkix bcpg bcmail bctls ; do
  cp -p build/artifacts/jdk1.5/jars/$bc-jdk15on-*.jar %{buildroot}%{_javadir}/$bc-%{version}.jar
  cp -p $bc.pom %{buildroot}%{_mavenpomdir}/JPP-$bc-%{version}.pom
  %add_to_maven_depmap org.bouncycastle $bc-jdk15on %{version} JPP $bc-%{version}
  %add_to_maven_depmap org.bouncycastle $bc-jdk15 %{version} JPP $bc-%{version}
  %add_to_maven_depmap org.bouncycastle $bc-jdk16 %{version} JPP $bc-%{version}
  mv %{buildroot}%{_mavendepmapfragdir}/%{name} \
     %{buildroot}%{_mavendepmapfragdir}/%{name}-$bc
done
mv %{buildroot}%{_mavendepmapfragdir}/%{name}-bcprov \
   %{buildroot}%{_mavendepmapfragdir}/%{name}

mkdir -p %{buildroot}%{_javadir}/gcj-endorsed
ln -s ../bcprov-%{version}.jar %{buildroot}%{_javadir}/gcj-endorsed

mkdir -p %{buildroot}%{_javadocdir}/%{name}
cp -pr build/artifacts/jdk1.5/javadoc/* %{buildroot}%{_javadocdir}/%{name}

%post
{
  # Rebuild the list of security providers in classpath.security
  suffix=security/classpath.security
  secfiles="/usr/lib/$suffix /usr/lib64/$suffix"

  for secfile in $secfiles
  do
    # check if this classpath.security file exists
    [ -f "$secfile" ] || continue

    sed -i '/^security\.provider\./d' "$secfile"

    count=0
    for provider in $(ls /etc/java/security/security.d)
    do
      count=$((count + 1))
      echo "security.provider.${count}=${provider#*-}" >> "$secfile"
    done
  done
} || :

%update_maven_depmap

%postun
if [ $1 -eq 0 ] ; then

  {
    # Rebuild the list of security providers in classpath.security
    suffix=security/classpath.security
    secfiles="/usr/lib/$suffix /usr/lib64/$suffix"

    for secfile in $secfiles
    do
      # check if this classpath.security file exists
      [ -f "$secfile" ] || continue

      sed -i '/^security\.provider\./d' "$secfile"

      count=0
      for provider in $(ls /etc/java/security/security.d)
      do
        count=$((count + 1))
        echo "security.provider.${count}=${provider#*-}" >> "$secfile"
      done
    done
  } || :

fi
%update_maven_depmap

%post pkix
%update_maven_depmap

%postun pkix
%update_maven_depmap

%post pg
%update_maven_depmap

%postun pg
%update_maven_depmap

%post mail
%update_maven_depmap

%postun mail
%update_maven_depmap

%post tls
%update_maven_depmap

%postun tls
%update_maven_depmap

%files
%{_javadir}/bcprov-%{version}.jar
%dir %{_javadir}/gcj-endorsed
%{_javadir}/gcj-endorsed/bcprov-%{version}.jar
%{_mavenpomdir}/JPP-bcprov-%{version}.pom
%config(noreplace) %{_mavendepmapfragdir}/%{name}
%config(noreplace) %{_sysconfdir}/java/security/security.d/2158-%{classname}
%doc docs/ core/docs/ *.html
%license build/artifacts/jdk1.5/bcprov-jdk15on-*/LICENSE.html

%files pkix
%{_javadir}/bcpkix-%{version}.jar
%{_mavenpomdir}/JPP-bcpkix-%{version}.pom
%config(noreplace) %{_mavendepmapfragdir}/%{name}-bcpkix
%license build/artifacts/jdk1.5/bcpkix-jdk15on-*/LICENSE.html

%files pg
%{_javadir}/bcpg-%{version}.jar
%{_mavenpomdir}/JPP-bcpg-%{version}.pom
%config(noreplace) %{_mavendepmapfragdir}/%{name}-bcpg
%license build/artifacts/jdk1.5/bcpg-jdk15on-*/LICENSE.html

%files mail
%{_javadir}/bcmail-%{version}.jar
%{_mavenpomdir}/JPP-bcmail-%{version}.pom
%config(noreplace) %{_mavendepmapfragdir}/%{name}-bcmail
%license build/artifacts/jdk1.5/bcmail-jdk15on-*/LICENSE.html

%files tls
%{_javadir}/bctls-%{version}.jar
%{_mavenpomdir}/JPP-bctls-%{version}.pom
%config(noreplace) %{_mavendepmapfragdir}/%{name}-bctls
%license build/artifacts/jdk1.5/bctls-jdk15on-*/LICENSE.html

%files javadoc
%doc %{_javadocdir}/%{name}
%license LICENSE.html

%changelog
* Wed Jan 24 2018 Mattias Ellert <mattias.ellert@physics.uu.se> - 1.58-1
- Parallel installable bouncycastle 1.58 package for EPEL 6
